@@ -91,7 +91,7 @@ public:
 
   void OnAbort(const char Reason[]) throw ()
   {
-    cerr << "Transactor " << Name() << " failed: " << Reason << endl;
+    cerr << "(Expected) Transactor " << Name() << " failed: " << Reason << endl;
   }
 
   void OnCommit()
@@ -133,7 +133,7 @@ int main(int argc, char *argv[])
     }
     catch (const exception &e)
     {
-      cerr << "Doomed transaction failed: " << e.what() << endl;
+      cerr << "(Expected) Doomed transaction failed: " << e.what() << endl;
     }
 
     pair<int,int> After;
